"""
    >>> s = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789'
    >>> s == morse2eng(eng2morse(s))
    True
"""


def eng2morse(s):
    """
       >>> eng2morse('A')
       '.-'
       >>> eng2morse('BAT')
       '-... .- -'
       >>> eng2morse('NVCC ROCKS!')
       '-. ...- -.-. -.-.   .-. --- -.-. -.- ... -.-.--'
    """
    e2m = {'A': '.-', 'B': '-...', 'C': '-.-.', 'D': '-..', 'E': '.',
           'F': '..-.', 'G': '--.', 'H': '....', 'I': '..', 'J': '.---',
           'K': '-.-', 'L': '.-..', 'M': '--', 'N': '-.', 'O': '---',
           'P': '.--.', 'Q': '--.-', 'R': '.-.', 'S': '...', 'T': '-',
           'U': '..-', 'V': '...-', 'W': '.--', 'X': '-..-', 'Y': '-.--',
           'Z': '--..', '0': '-----', '1': '.----', '2': '..---', '3': '...--',
           '4': '....-', '5': '.....', '6': '-....', '7': '--...',
           '8': '---..', '9': '----.', '.': '.-.-.-', ',': '--..--',
           '?': '..--..', "'": '.----.', '!': '-.-.--', '/': '-..-.',
           '(': '-.--.', ')': '-.--.-', '&': '.-...', ':': '---...',
           ';': '-.-.-.', '=': '-...-', '+': '.-.-.', '-': '-....-',
           '_': '..--.-', '"': '.-..-.', '$': '...-..-', '@': '.--.-.'}

    morse = ''

    for char in s:
        if char == ' ':
            morse += '  '
        elif char not in e2m:
            pass
        else:
            morse += e2m[char] + ' '

    return morse[:-1]


def morse2eng(s):
    """
      >>> morse2eng('-....')
      '6'
      >>> morse2eng('-.-. .- -   .. -.   - .... .   .... .- -')
      'CAT IN THE HAT'
    """
    m2e = {'.-': 'A', '-...': 'B', '-.-.': 'C', '-..': 'D', '.': 'E',
           '..-.': 'F', '--.': 'G', '....': 'H', '..': 'I', '.---': 'J',
           '-.-': 'K', '.-..': 'L', '--': 'M', '-.': 'N', '---': 'O',
           '.--.': 'P', '--.-': 'Q', '.-.': 'R', '...': 'S', '-': 'T',
           '..-': 'U', '...-': 'V', '.--': 'W', '-..-': 'X', '-.--': 'Y',
           '--..': 'Z', '-----': '0', '.----': '1', '..---': '2', '...--': '3',
           '....-': '4', '.....': '5', '-....': '6', '--...': '7',
           '---..': '8', '----.': '9', '.-.-.-': '.', '--..--': ',',
           '..--..': '?', '.----.': "'", '-.-.--': '!', '-..-.': '/',
           '-.--.': '(', '-.--.-': ')', '.-...': '&', '---...': ':',
           '-.-.-.': ';', '-...-': '=', '.-.-.': '+', '-....-': '-',
           '..--.-': '_', '.-..-.': '"', '...-..-': '$', '.--.-.': '@'}

    words = s.split('   ')
    english = ''

    for word in words:
        letters = word.split(' ')

        for letter in letters:
            if letter not in m2e:
                pass
            else:
                english += m2e[letter]

        english += ' '

    return english[:-1]


if __name__ == '__main__':
    import doctest
    doctest.testmod()
